︠0cff0503-5616-4c0e-89e5-793c4e4f3f01s︠
import sys

def continued_fraction(r):
    a, b = floor(r), r - floor(r)
    value = [a]
    while b != 0:
        a, b = floor(1/b), 1/b - floor(1/b)
        value += [a]
    return value

def positive_rational(n):
    """ Returns the n-th term of the Calkin-Wilf sequence """
    b = bin(n)[2:]
    ld = '1'
    c = 0
    cf = []
    for i in range(len(b)-1, -1, -1):
        if b[i] == ld:
            c += 1
        else:
            cf += [c]
            ld = b[i]
            c = 1
    cf += [c]
    r = cf[-1]
    for k in range(len(cf)-2, -1, -1):
        r = cf[k] + 1 / r
    return r

def rational_number(n):
    """ Returns the n-th rational number """
    if n == 0:
        return 0
    elif n % 2 == 0:
        return positive_rational(n // 2)
    else:
        return -rational_number(n+1)

def polynomial(n):
    """ Returns the n-th monic polynomial as a list of coefficients """
    if n == 1:
        return [1]
    else:
        cf = continued_fraction(positive_rational(n))
        if len(cf) == 1:
            cf = [cf[0] - 2]
        else:
            cf = [cf[0]] + [k-1 for k in cf[1:-1]] + [cf[-1]-2]
        return [rational_number(k) for k in cf] + [1]

def polynomial_function(p):
    """ list of coefficients --> function """
    def u(t):
        value = 0
        for i in range(len(p)):
            value += p[i] * (t ** i)
        return value
    return u

beta1 = lambda t: exp(-1/t) if t > 0 else 0

beta = lambda a, b, t: beta1(b-t) / (beta1(b-t) + beta1(t-a))  # smooth transition

h = lambda d, lambda_, t: 1 - min(0.5, lambda_) / (log(t - d + 1) + 1) if t > d else 1 - min(0.5, lambda_)

coef_lin_map = lambda a, b, c, d: ((b*c - a*d) / (b - a), (d - c) / (b - a))  # coefficients of the linear map [a,b] -> [c,d]

lower_bound = lambda p: p[0] + sum([c - abs(c) for c in p[1:]]) / 2

upper_bound = lambda p: p[0] + sum([c + abs(c) for c in p[1:]]) / 2

upper_bound_for_derivative = lambda p, a, b: sum([k * abs(p[k]) * (max(abs(a), abs(b)) ** (k-1)) for k in range(1, len(p))])

def sigma(d, lambda_):
    def sigma1(t):
        if t >= d:
            m = round(t / (2*d))
            if t == (2*m+1)*d:  # preventing possible rounding error
                m += 1
            p = polynomial(m)
            um = polynomial_function(p)
            if t <= 2*m*d:
                M = h(d, lambda_, (2*m+1)*d)
                if len(p) == 1:  # um is constant
                    value = (1 + M) / 2
                else:
                    A1, A2 = lower_bound(p), upper_bound(p)
                    am, bm = coef_lin_map(A1, A2, (2*M + 1)/3, (M + 2)/3)
                    value = am + bm * um(t / d - 2 * m + 1)
            else:
                K = (sigma1(2*m*d) + sigma1((2*m+1)*d)) / 2
                if t - 2*m*d < d / 2:
                    M = h(d, lambda_, (2*m+1)*d)
                    if len(p) == 1:  # um is constant
                        v = (1 + M) / 2
                        delta = d / 2
                    else:
                        A1, A2 = lower_bound(p), upper_bound(p)
                        am, bm = coef_lin_map(A1, A2, (2*M + 1)/3, (M + 2)/3)
                        v = am + bm * um(t / d - 2 * m + 1)
                        epsilon = (1 - M) / 6
                        C = upper_bound_for_derivative(p, 1, 1.5)
                        delta = min(d / 2, (epsilon * d) / (bm * C))
                    value = K - (K - v) * beta(2*m*d, 2*m*d + delta, t)
                else:
                    p = polynomial(m+1)
                    um = polynomial_function(p)
                    M = h(d, lambda_, (2*m+3)*d)
                    if len(p) == 1:  # um is constant
                        v = (1 + M) / 2
                        delta = d / 2
                    else:
                        A1, A2 = lower_bound(p), upper_bound(p)
                        am, bm = coef_lin_map(A1, A2, (2*M + 1)/3, (M + 2)/3)
                        v = am + bm * um(t / d - 2 * m - 1)
                        epsilon = (1 - M) / 6
                        C = upper_bound_for_derivative(p, -0.5, 0)
                        delta = min(d / 2, (epsilon * d) / (bm * C))
                    value = K - (K - v) * (1 - beta((2*m+1)*d - delta, (2*m+1)*d, t))
        else:
            value = (1 + h(d, lambda_, 3*d)) * (1 - beta1(d - t)) / 2
        return value
    return sigma1



def anti_fusc(r):
    if r == 0:
        return 0
    cf = continued_fraction(r)
    if len(cf) % 2 == 0:
        cf = cf[:-1] + [cf[-1]-1] + [1]
    value = 0
    for i in range(len(cf)-1, -1, -1):
        try:
            value = value * (2 ** cf[i])
        except:     # Error: Position of the polynomial is too large to calculate
            return -2
        if i % 2 == 0:
            value += (2 ** cf[i]) - 1
    return value

def anti_rational(r):
    """ Returns the index of r """
    if r >= 0:
        return 2 * anti_fusc(r)
    else:
        return 2 * anti_fusc(-r) - 1

def anti_polynomial(p_):
    if p_ == [1]:
        return 1
    del p_[-1]
    p = [anti_rational(r) for r in p_]
    if len(p) == 1:
        p = [p[0] + 2]
    else:
        p = [p[0]] + [i+1 for i in p[1:-1]] + [p[-1]+2]
    r = p[-1]
    for k in range(len(p)-2, -1, -1):
        try:
            r = p[k] + 1 / r
        except (MemoryError, OverflowError):     # Error: Position of the polynomial is too large to calculate
            return 0
    try:
        return anti_fusc(r)
    except (MemoryError, OverflowError):     # Error: Position of the polynomial is too large to calculate
        return 0

def rational_approximating_number(x, epsilon):
    for k in range(1, ceil(1 / (2 * epsilon)) + 1):
        y = round(x * k) / k
        if abs(x - y) <= epsilon:
            return y

def rational_approximating_Taylor_polynomial(f, a, b, epsilon):
    epsilon1 = epsilon / 2
    n = 0
    err = plot(abs(diff(f, x)), (x, a, b)).ymax() * (b - a) / 2
    while (err >= epsilon1) & (n < 101):
        n += 1
        err = plot(abs(diff(f, x, n+1)), (x, a, b)).ymax() * ((b - a) ** (n+1)) / (factorial(n+1) * (2 ** (n+1)))
    if (n == 101):
        return [0, 0]
    fp = taylor(f, x, (a + b) / 2, n).coefficients(sparse=False)
    tp = []
    for k in range(len(fp)):
        tt = 0
        for m in range(k, len(fp)):
            tt += fp[m] * (a ** (m-k)) * binomial(m, k)
        tp += [tt * ((b - a) ** k)]
    epsilon2 = epsilon - err
    p = []
    for m in range(len(tp)-1, -1, -1):
        if m == 0:
            epsilon2 *= 2
        r = rational_approximating_number(tp[m].n(), epsilon2 / 2)
        p = [r] + p
        epsilon2 -= abs(tp[m].n() - r.n())
    while (p[-1] == 0) & (len(p) > 1):
        del p[-1]
    return p

def coefficients_of_approximation(lambda_, f, a, b, epsilon):
    d = b - a
    p = rational_approximating_Taylor_polynomial(f, a, b, epsilon)
    if p == [0, 0]:
        return [0, 0, 0, 1]
    plc = p[-1]
    monic = [k / plc for k in p] + [1] if plc != 0 else [1]
    m = anti_polynomial(monic)
    if m <= 0:                 # Error!
        return [0, 0, 0, 0]
    M = h(d, lambda_, (2*m+1)*d)
    if m == 1:
        am, bm = 1 / 2, h(d, lambda_, 3*d) / 2
    else:
        A1, A2 = lower_bound(monic), upper_bound(monic)
        am, bm = coef_lin_map(A1, A2, (2*M + 1)/3, (M + 2)/3)
    c1, c2 = plc / bm, 2 * am * plc / (bm * (1 + h(d, lambda_, 3*d)))
    return [c1, c2, b - (2 * m * d), 2 * a - b]





def graph_of_sigma(d, lambda_, xmin, xmax, text_ = ""):
    s = sigma(d, lambda_)
    h_ = lambda t: 1 - min(0.5, lambda_) / (log(t - d + 1) + 1) if t >= d else 1 - min(0.5, lambda_)
    image = plot(s, (x, xmin, xmax), color = 'blue') + plot(h_, (x, xmin, xmax), color = 'red', linestyle = "--") + plot(1, (x, xmin, xmax), color = 'green', linestyle = "--")
    if text_ == "lambda":
        image += text(r"$\lambda = " + str(lambda_).rstrip('0') + "$", (0.95 * xmax, 0.5 * image.ymin() + 0.5 * image.ymax()), fontsize = 15, rgbcolor = (0, 0, 0))
    elif text_ == "s":
        image += text(r"$s = " + str(d).rstrip('0.') + "$", (0.95 * xmax, 0.5 * image.ymin() + 0.5 * image.ymax()), fontsize = 15, rgbcolor = (0, 0, 0))
    return image

#graph_of_sigma(2.0, 0.250, 0, 20).save('monic-0-20.png')
#graphics_array([[graph_of_sigma(2.0, 0.6, 0, 100, True)], [graph_of_sigma(2.0, 0.3, 0, 100, True)], [graph_of_sigma(2.0, 0.1, 0, 100, True)]]).save('monic-0-100.png', figsize = [8, 12])
#graph_of_sigma(3.0, 0.5, 0, 50).save('monic-0-50.png')
#graphics_array([[graph_of_sigma(1.0, 0.5, 0, 100, "lambda"), graph_of_sigma(1.0, 0.2, 0, 100, "lambda")], [graph_of_sigma(1.0, 0.1, 0, 100, "lambda"), graph_of_sigma(1.0, 0.05, 0, 100, "lambda")]]).save('monic-0-100_lambda.png', figsize = [12, 6])
#graphics_array([[graph_of_sigma(1.0, 0.75, 0, 100, "s"), graph_of_sigma(3.0, 0.75, 0, 100, "s")], [graph_of_sigma(6.0, 0.75, 0, 100, "s"), graph_of_sigma(9.0, 0.75, 0, 100, "s")]]).save('monic-0-100_s.png', figsize = [12, 6])

sig = sigma(2, 0.25)
tbl = []
arg = [0.4 * i for i in range(0, 50)]
for i in range(10):
    tbl += [[round(arg[i], 5), round(sig(arg[i]), 5), round(arg[10+i], 5), round(sig(arg[10+i]), 5), round(arg[20+i], 5), round(sig(arg[20+i]), 5), round(arg[30+i], 5), round(sig(arg[30+i]), 5), round(arg[40+i], 5), round(sig(arg[40+i]), 5)]]
#latex(table(tbl, frame=True))

sig2 = sigma(3, 0.5)
tbl2 = []
for i in range(10):
    tbl2 += [[round(i, 5), round(sig2(i), 5), round(10+i, 5), round(sig2(10+i), 5), round(20+i, 5), round(sig2(20+i), 5), round(30+i, 5), round(sig2(30+i), 5), round(40+i, 5), round(sig2(40+i), 5)]]
#latex(table(tbl2, frame=True))

def print_table_of_parameters(f, a, b, errors):
    tbl = []
    for epsilon in errors:
        c1, c2, theta1, theta2 = coefficients_of_approximation(1/4, f, a, b, epsilon)
        tbl += [[2, c1.n(25), c2.n(25), theta1.n(25), theta2, epsilon.n()]]
    print latex(table(tbl, header_row=True, frame=True))

#f(x) = 1 + x + x^2 / 2 + x^3 / 6 + x^4 / 24 + x^5 / 120 + x^6 / 720; print_table_of_parameters(f, -1, 1, [0.95, 0.6, 0.35, 0.1, 0.04, 0.01])
#f(x) = 4 * x / (4 + x^2); print_table_of_parameters(f, -1, 1, [0.95, 0.6, 0.35, 0.1, 0.04, 0.01])
#f(x) = sin(x) - x * cos(x + 1); print_table_of_parameters(f, -1, 1, [0.95, 0.6, 0.35, 0.1, 0.04, 0.01])


def graph_with_approximators(f, a, b, errors, colors, linestyles):
    image = plot(f, (x, a, b), color = 'blue', legend_label = '$f$')
    for i in range(len(errors)):
        p = polynomial_function(rational_approximating_Taylor_polynomial(f, a, b, errors[i])); pol = lambda t: p((t - a) / (b - a))
        image += plot(pol, (x, a, b), color = colors[i], linestyle = linestyles[i], legend_label = '$\mathcal{N}\ $ ($\epsilon = ' + str(errors[i]).rstrip('0') + '$)')
    return image

#f(x) = 1 + x + x^2 / 2 + x^3 / 6 + x^4 / 24 + x^5 / 120 + x^6 / 720; graph_with_approximators(f, -1, 1, [0.6, 0.35, 0.1], [(1, 0, 0), (2/3, 0, 1/3), (1/3, 0, 2/3)], [":", "-.", "--"]).save('monic-f1.png')
#f(x) = 4 * x / (4 + x^2); graph_with_approximators(f, -1, 1, [0.6, 0.35, 0.1], [(1, 0, 0), (2/3, 0, 1/3), (1/3, 0, 2/3)], [":", "-.", "--"]).save('monic-f2.png')
#f(x) = sin(x) - x * cos(x + 1); graph_with_approximators(f, -1, 1, [0.6, 0.35, 0.1], [(1, 0, 0), (2/3, 0, 1/3), (1/3, 0, 2/3)], [":", "-.", "--"]).save('monic-f3.png')


@interact
def _(a_b = range_slider(-10.0, 10.0, 1, (-1.0, 1.0), label = "[a, b]: "),
               lambda_ = slider(0.01, 1.0, step_size=0.001, default=0.2500, label="λ: "),
               x_range = range_slider(-10.0, 100.0, 1, (0, 20.0), label = "range: ")):
    d = a_b[1] - a_b[0]
    s = sigma(d, lambda_)
    h = lambda t: 1 - min(0.5, lambda_) / (log(t - d + 1) + 1) if t >= d else 1 - min(0.5, lambda_)
    xmin, xmax = x_range[0], x_range[1]
    show(plot(s, (x, xmin, xmax), color = 'blue') + plot(h, (x, xmin, xmax), color = 'red', linestyle = "--") + plot(1, (x, xmin, xmax), color = 'green', linestyle = "--")) #, aspect_ratio = 1


@interact
def __(a_b = range_slider(-10.0, 10.0, 1, (-1.0, 1.0), label = "[a, b]: "),
               lambda_ = slider(0.01, 1.0, step_size=0.001, default=0.2500, label="λ: "),
               t = input_box(default = 0, label = "t: ")):
    d = a_b[1] - a_b[0]
    s = sigma(d, lambda_)
    sys.stdout.write('σ(')
    sys.stdout.write(str(t.n()))
    sys.stdout.write(') = ')
    sys.stdout.write(str(s(t).n()))


@interact
def ___(a_b = range_slider(-10.0, 10.0, 1, (-1.0, 1.0), label = "[a, b]: "),
               lambda_ = slider(0.01, 1.0, step_size=0.001, default=0.2500, label="λ: "),
               epsilon = slider(0.01, 1.0, step_size=0.01, default=1.0, label="ε: "),
               f = input_box(default = sin(x), label = "f: ")):
    p = rational_approximating_Taylor_polynomial(f, a_b[0], a_b[1], epsilon)
    if p == [0, 0]:
        show(plot(f, (x, a_b[0], a_b[1]), color = 'blue', legend_label = '$f$'))
        print "None of the first 100 Taylor polynomials approximates f with the given accuracy."
    else:
        polf = polynomial_function(p)
        pol1 = lambda t: polf((t - a_b[0]) / (a_b[1] - a_b[0]))
        show(plot(f, (x, a_b[0], a_b[1]), color = 'blue', legend_label = '$f$') + plot(pol1, (x, a_b[0], a_b[1]), color = 'red', linestyle = "--", legend_label = '$\mathcal{N}$'))
        c1, c2, theta1, theta2 = coefficients_of_approximation(lambda_, f, a_b[0], a_b[1], epsilon)
        if theta2 < 0:
            print "c₁ =", c1, ", c₂ =", c2, ", θ₁ =", theta1, ", θ₂ =", theta2
        elif theta2 == 0:
            print "Error: Position of the polynomial is too large to calculate."




︡2237d2a4-7a30-4443-9985-db7a8da2816c︡{"interact":{"controls":[{"animate":true,"control_type":"range-slider","default":[9,11],"display_value":true,"label":"[a, b]: ","vals":["-10.0000000000000","-9.00000000000000","-8.00000000000000","-7.00000000000000","-6.00000000000000","-5.00000000000000","-4.00000000000000","-3.00000000000000","-2.00000000000000","-1.00000000000000","0.000000000000000","1.00000000000000","2.00000000000000","3.00000000000000","4.00000000000000","5.00000000000000","6.00000000000000","7.00000000000000","8.00000000000000","9.00000000000000","10.0000000000000"],"var":"a_b","width":null},{"animate":true,"control_type":"slider","default":240,"display_value":true,"label":"λ: ","vals":["0.0100000000000000","0.0110000000000000","0.0120000000000000","0.0130000000000000","0.0140000000000000","0.0150000000000000","0.0160000000000000","0.0170000000000000","0.0180000000000000","0.0190000000000000","0.0200000000000000","0.0210000000000000","0.0220000000000000","0.0230000000000000","0.0240000000000000","0.0250000000000000","0.0260000000000000","0.0270000000000000","0.0280000000000000","0.0290000000000000","0.0300000000000000","0.0310000000000000","0.0320000000000000","0.0330000000000000","0.0340000000000000","0.0350000000000000","0.0360000000000000","0.0370000000000000","0.0380000000000000","0.0390000000000000","0.0400000000000000","0.0410000000000000","0.0420000000000000","0.0430000000000000","0.0440000000000000","0.0450000000000000","0.0460000000000000","0.0470000000000000","0.0480000000000000","0.0490000000000000","0.0500000000000000","0.0510000000000000","0.0520000000000000","0.0530000000000000","0.0540000000000000","0.0550000000000000","0.0560000000000000","0.0570000000000000","0.0580000000000000","0.0590000000000000","0.0600000000000000","0.0610000000000000","0.0620000000000000","0.0630000000000000","0.0640000000000000","0.0650000000000000","0.0660000000000000","0.0670000000000000","0.0680000000000000","0.0690000000000000","0.0700000000000000","0.0710000000000000","0.0720000000000001","0.0730000000000001","0.0740000000000001","0.0750000000000001","0.0760000000000001","0.0770000000000001","0.0780000000000001","0.0790000000000001","0.0800000000000001","0.0810000000000001","0.0820000000000001","0.0830000000000001","0.0840000000000001","0.0850000000000001","0.0860000000000001","0.0870000000000001","0.0880000000000001","0.0890000000000001","0.0900000000000001","0.0910000000000001","0.0920000000000001","0.0930000000000001","0.0940000000000001","0.0950000000000001","0.0960000000000001","0.0970000000000001","0.0980000000000001","0.0990000000000001","0.100000000000000","0.101000000000000","0.102000000000000","0.103000000000000","0.104000000000000","0.105000000000000","0.106000000000000","0.107000000000000","0.108000000000000","0.109000000000000","0.110000000000000","0.111000000000000","0.112000000000000","0.113000000000000","0.114000000000000","0.115000000000000","0.116000000000000","0.117000000000000","0.118000000000000","0.119000000000000","0.120000000000000","0.121000000000000","0.122000000000000","0.123000000000000","0.124000000000000","0.125000000000000","0.126000000000000","0.127000000000000","0.128000000000000","0.129000000000000","0.130000000000000","0.131000000000000","0.132000000000000","0.133000000000000","0.134000000000000","0.135000000000000","0.136000000000000","0.137000000000000","0.138000000000000","0.139000000000000","0.140000000000000","0.141000000000000","0.142000000000000","0.143000000000000","0.144000000000000","0.145000000000000","0.146000000000000","0.147000000000000","0.148000000000000","0.149000000000000","0.150000000000000","0.151000000000000","0.152000000000000","0.153000000000000","0.154000000000000","0.155000000000000","0.156000000000000","0.157000000000000","0.158000000000000","0.159000000000000","0.160000000000000","0.161000000000000","0.162000000000000","0.163000000000000","0.164000000000000","0.165000000000000","0.166000000000000","0.167000000000000","0.168000000000000","0.169000000000000","0.170000000000000","0.171000000000000","0.172000000000000","0.173000000000000","0.174000000000000","0.175000000000000","0.176000000000000","0.177000000000000","0.178000000000000","0.179000000000000","0.180000000000000","0.181000000000000","0.182000000000000","0.183000000000000","0.184000000000000","0.185000000000000","0.186000000000000","0.187000000000000","0.188000000000000","0.189000000000000","0.190000000000000","0.191000000000000","0.192000000000000","0.193000000000000","0.194000000000000","0.195000000000000","0.196000000000000","0.197000000000000","0.198000000000000","0.199000000000000","0.200000000000000","0.201000000000000","0.202000000000000","0.203000000000000","0.204000000000000","0.205000000000000","0.206000000000000","0.207000000000000","0.208000000000000","0.209000000000000","0.210000000000000","0.211000000000000","0.212000000000000","0.213000000000000","0.214000000000000","0.215000000000000","0.216000000000000","0.217000000000000","0.218000000000000","0.219000000000000","0.220000000000000","0.221000000000000","0.222000000000000","0.223000000000000","0.224000000000000","0.225000000000000","0.226000000000000","0.227000000000000","0.228000000000000","0.229000000000000","0.230000000000000","0.231000000000000","0.232000000000000","0.233000000000000","0.234000000000000","0.235000000000000","0.236000000000000","0.237000000000000","0.238000000000000","0.239000000000000","0.240000000000000","0.241000000000000","0.242000000000000","0.243000000000000","0.244000000000000","0.245000000000000","0.246000000000000","0.247000000000000","0.248000000000000","0.249000000000000","0.250000000000000","0.251000000000000","0.252000000000000","0.253000000000000","0.254000000000000","0.255000000000000","0.256000000000000","0.257000000000000","0.258000000000000","0.259000000000000","0.260000000000000","0.261000000000000","0.262000000000000","0.263000000000000","0.264000000000000","0.265000000000000","0.266000000000000","0.267000000000000","0.268000000000000","0.269000000000000","0.270000000000000","0.271000000000000","0.272000000000000","0.273000000000000","0.274000000000000","0.275000000000000","0.276000000000000","0.277000000000000","0.278000000000000","0.279000000000000","0.280000000000000","0.281000000000000","0.282000000000000","0.283000000000000","0.284000000000000","0.285000000000000","0.286000000000000","0.287000000000000","0.288000000000000","0.289000000000000","0.290000000000000","0.291000000000000","0.292000000000000","0.293000000000000","0.294000000000000","0.295000000000000","0.296000000000000","0.297000000000000","0.298000000000000","0.299000000000000","0.300000000000000","0.301000000000000","0.302000000000000","0.303000000000000","0.304000000000000","0.305000000000000","0.306000000000000","0.307000000000000","0.308000000000000","0.309000000000000","0.310000000000000","0.311000000000000","0.312000000000000","0.313000000000000","0.314000000000000","0.315000000000000","0.316000000000000","0.317000000000000","0.318000000000000","0.319000000000000","0.320000000000000","0.321000000000000","0.322000000000000","0.323000000000000","0.324000000000000","0.325000000000000","0.326000000000000","0.327000000000000","0.328000000000000","0.329000000000000","0.330000000000000","0.331000000000000","0.332000000000000","0.333000000000000","0.334000000000000","0.335000000000000","0.336000000000000","0.337000000000000","0.338000000000000","0.339000000000000","0.340000000000000","0.341000000000000","0.342000000000000","0.343000000000000","0.344000000000000","0.345000000000000","0.346000000000000","0.347000000000000","0.348000000000000","0.349000000000000","0.350000000000000","0.351000000000000","0.352000000000000","0.353000000000000","0.354000000000000","0.355000000000000","0.356000000000000","0.357000000000000","0.358000000000000","0.359000000000000","0.360000000000000","0.361000000000000","0.362000000000000","0.363000000000000","0.364000000000000","0.365000000000000","0.366000000000000","0.367000000000000","0.368000000000000","0.369000000000000","0.370000000000000","0.371000000000000","0.372000000000000","0.373000000000000","0.374000000000000","0.375000000000000","0.376000000000000","0.377000000000000","0.378000000000000","0.379000000000000","0.380000000000000","0.381000000000000","0.382000000000000","0.383000000000000","0.384000000000000","0.385000000000000","0.386000000000000","0.387000000000000","0.388000000000000","0.389000000000000","0.390000000000000","0.391000000000000","0.392000000000000","0.393000000000000","0.394000000000000","0.395000000000000","0.396000000000000","0.397000000000000","0.398000000000000","0.399000000000000","0.400000000000000","0.401000000000000","0.402000000000000","0.403000000000000","0.404000000000000","0.405000000000000","0.406000000000000","0.407000000000000","0.408000000000000","0.409000000000000","0.410000000000000","0.411000000000000","0.412000000000000","0.413000000000000","0.414000000000000","0.415000000000000","0.416000000000000","0.417000000000000","0.418000000000000","0.419000000000000","0.420000000000000","0.421000000000000","0.422000000000000","0.423000000000000","0.424000000000000","0.425000000000000","0.426000000000000","0.427000000000000","0.428000000000000","0.429000000000000","0.430000000000000","0.431000000000000","0.432000000000000","0.433000000000000","0.434000000000000","0.435000000000000","0.436000000000000","0.437000000000000","0.438000000000000","0.439000000000000","0.440000000000000","0.441000000000000","0.442000000000000","0.443000000000000","0.444000000000000","0.445000000000000","0.446000000000000","0.447000000000000","0.448000000000000","0.449000000000000","0.450000000000000","0.451000000000000","0.452000000000000","0.453000000000000","0.454000000000000","0.455000000000000","0.456000000000000","0.457000000000000","0.458000000000000","0.459000000000000","0.460000000000000","0.461000000000000","0.462000000000000","0.463000000000000","0.464000000000000","0.465000000000000","0.466000000000000","0.467000000000000","0.468000000000000","0.469000000000000","0.470000000000000","0.471000000000000","0.472000000000000","0.473000000000000","0.474000000000000","0.475000000000000","0.476000000000000","0.477000000000000","0.478000000000000","0.479000000000000","0.480000000000000","0.481000000000000","0.482000000000000","0.483000000000000","0.484000000000000","0.485000000000000","0.486000000000000","0.487000000000000","0.488000000000000","0.489000000000000","0.490000000000000","0.491000000000000","0.492000000000000","0.493000000000000","0.494000000000000","0.495000000000000","0.496000000000000","0.497000000000000","0.498000000000000","0.499000000000000","0.500000000000000","0.501000000000000","0.502000000000000","0.503000000000000","0.504000000000000","0.505000000000000","0.506000000000000","0.507000000000000","0.508000000000000","0.509000000000000","0.510000000000000","0.511000000000000","0.512000000000000","0.513000000000000","0.514000000000000","0.515000000000000","0.516000000000000","0.517000000000000","0.518000000000000","0.519000000000000","0.520000000000000","0.521000000000000","0.522000000000000","0.523000000000000","0.524000000000000","0.525000000000000","0.526000000000000","0.527000000000000","0.528000000000000","0.529000000000000","0.530000000000000","0.531000000000000","0.532000000000000","0.533000000000000","0.534000000000000","0.535000000000000","0.536000000000000","0.537000000000000","0.538000000000000","0.539000000000000","0.540000000000000","0.541000000000000","0.542000000000000","0.543000000000000","0.544000000000000","0.545000000000000","0.546000000000000","0.547000000000000","0.548000000000000","0.549000000000000","0.550000000000000","0.551000000000000","0.552000000000000","0.553000000000000","0.554000000000000","0.555000000000000","0.556000000000000","0.557000000000000","0.558000000000000","0.559000000000000","0.560000000000000","0.561000000000000","0.562000000000000","0.563000000000000","0.564000000000000","0.565000000000000","0.566000000000000","0.567000000000000","0.568000000000000","0.569000000000000","0.570000000000000","0.571000000000000","0.572000000000000","0.573000000000000","0.574000000000000","0.575000000000000","0.576000000000000","0.577000000000000","0.578000000000000","0.579000000000000","0.580000000000000","0.581000000000000","0.582000000000000","0.583000000000000","0.584000000000000","0.585000000000000","0.586000000000000","0.587000000000000","0.588000000000000","0.589000000000000","0.590000000000000","0.591000000000000","0.592000000000000","0.593000000000000","0.594000000000000","0.595000000000000","0.596000000000000","0.597000000000000","0.598000000000000","0.599000000000000","0.600000000000000","0.601000000000000","0.602000000000000","0.603000000000000","0.604000000000000","0.605000000000000","0.606000000000000","0.607000000000000","0.608000000000000","0.609000000000000","0.610000000000000","0.611000000000000","0.612000000000000","0.613000000000000","0.614000000000000","0.615000000000000","0.616000000000000","0.617000000000000","0.618000000000000","0.619000000000000","0.620000000000000","0.621000000000000","0.622000000000000","0.623000000000000","0.624000000000000","0.625000000000000","0.626000000000000","0.627000000000000","0.628000000000000","0.629000000000000","0.630000000000000","0.631000000000000","0.632000000000000","0.633000000000000","0.634000000000000","0.635000000000000","0.636000000000000","0.637000000000000","0.638000000000000","0.639000000000000","0.640000000000000","0.641000000000000","0.642000000000000","0.643000000000000","0.644000000000000","0.645000000000000","0.646000000000000","0.647000000000000","0.648000000000000","0.649000000000000","0.650000000000000","0.651000000000000","0.652000000000000","0.653000000000000","0.654000000000000","0.655000000000000","0.656000000000000","0.657000000000000","0.658000000000000","0.659000000000000","0.660000000000000","0.661000000000000","0.662000000000000","0.663000000000000","0.664000000000000","0.665000000000000","0.666000000000000","0.667000000000000","0.668000000000000","0.669000000000000","0.670000000000000","0.671000000000000","0.672000000000000","0.673000000000000","0.674000000000000","0.675000000000000","0.676000000000000","0.677000000000000","0.678000000000000","0.679000000000000","0.680000000000000","0.681000000000000","0.682000000000000","0.683000000000000","0.684000000000000","0.685000000000000","0.686000000000000","0.687000000000000","0.688000000000001","0.689000000000001","0.690000000000001","0.691000000000001","0.692000000000001","0.693000000000001","0.694000000000001","0.695000000000001","0.696000000000001","0.697000000000001","0.698000000000001","0.699000000000001","0.700000000000001","0.701000000000001","0.702000000000001","0.703000000000001","0.704000000000001","0.705000000000001","0.706000000000001","0.707000000000001","0.708000000000001","0.709000000000001","0.710000000000001","0.711000000000001","0.712000000000001","0.713000000000001","0.714000000000001","0.715000000000001","0.716000000000001","0.717000000000001","0.718000000000001","0.719000000000001","0.720000000000001","0.721000000000001","0.722000000000001","0.723000000000001","0.724000000000001","0.725000000000001","0.726000000000001","0.727000000000001","0.728000000000001","0.729000000000001","0.730000000000001","0.731000000000001","0.732000000000001","0.733000000000001","0.734000000000001","0.735000000000001","0.736000000000001","0.737000000000001","0.738000000000001","0.739000000000001","0.740000000000001","0.741000000000001","0.742000000000001","0.743000000000001","0.744000000000001","0.745000000000001","0.746000000000001","0.747000000000001","0.748000000000001","0.749000000000001","0.750000000000001","0.751000000000001","0.752000000000001","0.753000000000001","0.754000000000001","0.755000000000001","0.756000000000001","0.757000000000001","0.758000000000001","0.759000000000001","0.760000000000001","0.761000000000001","0.762000000000001","0.763000000000001","0.764000000000001","0.765000000000001","0.766000000000001","0.767000000000001","0.768000000000001","0.769000000000001","0.770000000000001","0.771000000000001","0.772000000000001","0.773000000000001","0.774000000000001","0.775000000000001","0.776000000000001","0.777000000000001","0.778000000000001","0.779000000000001","0.780000000000001","0.781000000000001","0.782000000000001","0.783000000000001","0.784000000000001","0.785000000000001","0.786000000000001","0.787000000000001","0.788000000000001","0.789000000000001","0.790000000000001","0.791000000000001","0.792000000000001","0.793000000000001","0.794000000000001","0.795000000000001","0.796000000000001","0.797000000000001","0.798000000000001","0.799000000000001","0.800000000000001","0.801000000000001","0.802000000000001","0.803000000000001","0.804000000000001","0.805000000000001","0.806000000000001","0.807000000000001","0.808000000000001","0.809000000000001","0.810000000000001","0.811000000000001","0.812000000000001","0.813000000000001","0.814000000000001","0.815000000000001","0.816000000000001","0.817000000000001","0.818000000000001","0.819000000000001","0.820000000000001","0.821000000000001","0.822000000000001","0.823000000000001","0.824000000000001","0.825000000000001","0.826000000000001","0.827000000000001","0.828000000000001","0.829000000000001","0.830000000000001","0.831000000000001","0.832000000000001","0.833000000000001","0.834000000000001","0.835000000000001","0.836000000000001","0.837000000000001","0.838000000000001","0.839000000000001","0.840000000000001","0.841000000000001","0.842000000000001","0.843000000000001","0.844000000000001","0.845000000000001","0.846000000000001","0.847000000000001","0.848000000000001","0.849000000000001","0.850000000000001","0.851000000000001","0.852000000000001","0.853000000000001","0.854000000000001","0.855000000000001","0.856000000000001","0.857000000000001","0.858000000000001","0.859000000000001","0.860000000000001","0.861000000000001","0.862000000000001","0.863000000000001","0.864000000000001","0.865000000000001","0.866000000000001","0.867000000000001","0.868000000000001","0.869000000000001","0.870000000000001","0.871000000000001","0.872000000000001","0.873000000000001","0.874000000000001","0.875000000000001","0.876000000000001","0.877000000000001","0.878000000000001","0.879000000000001","0.880000000000001","0.881000000000001","0.882000000000001","0.883000000000001","0.884000000000001","0.885000000000001","0.886000000000001","0.887000000000001","0.888000000000001","0.889000000000001","0.890000000000001","0.891000000000001","0.892000000000001","0.893000000000001","0.894000000000001","0.895000000000001","0.896000000000001","0.897000000000001","0.898000000000001","0.899000000000001","0.900000000000001","0.901000000000001","0.902000000000001","0.903000000000001","0.904000000000001","0.905000000000001","0.906000000000001","0.907000000000001","0.908000000000001","0.909000000000001","0.910000000000001","0.911000000000001","0.912000000000001","0.913000000000001","0.914000000000001","0.915000000000001","0.916000000000001","0.917000000000001","0.918000000000001","0.919000000000001","0.920000000000001","0.921000000000001","0.922000000000001","0.923000000000001","0.924000000000001","0.925000000000001","0.926000000000001","0.927000000000001","0.928000000000001","0.929000000000001","0.930000000000001","0.931000000000001","0.932000000000001","0.933000000000001","0.934000000000001","0.935000000000001","0.936000000000001","0.937000000000001","0.938000000000001","0.939000000000001","0.940000000000001","0.941000000000001","0.942000000000001","0.943000000000001","0.944000000000001","0.945000000000001","0.946000000000001","0.947000000000001","0.948000000000001","0.949000000000001","0.950000000000001","0.951000000000001","0.952000000000001","0.953000000000001","0.954000000000001","0.955000000000001","0.956000000000001","0.957000000000001","0.958000000000001","0.959000000000001","0.960000000000001","0.961000000000001","0.962000000000001","0.963000000000001","0.964000000000001","0.965000000000001","0.966000000000001","0.967000000000001","0.968000000000001","0.969000000000001","0.970000000000001","0.971000000000001","0.972000000000001","0.973000000000001","0.974000000000001","0.975000000000001","0.976000000000001","0.977000000000001","0.978000000000001","0.979000000000001","0.980000000000001","0.981000000000001","0.982000000000001","0.983000000000001","0.984000000000001","0.985000000000001","0.986000000000001","0.987000000000001","0.988000000000001","0.989000000000001","0.990000000000001","0.991000000000001","0.992000000000001","0.993000000000001","0.994000000000001","0.995000000000001","0.996000000000001","0.997000000000001","0.998000000000001","0.999000000000001","1.00000000000000"],"var":"lambda_","width":null},{"animate":true,"control_type":"range-slider","default":[10,30],"display_value":true,"label":"range: ","vals":["-10.0000000000000","-9.00000000000000","-8.00000000000000","-7.00000000000000","-6.00000000000000","-5.00000000000000","-4.00000000000000","-3.00000000000000","-2.00000000000000","-1.00000000000000","0.000000000000000","1.00000000000000","2.00000000000000","3.00000000000000","4.00000000000000","5.00000000000000","6.00000000000000","7.00000000000000","8.00000000000000","9.00000000000000","10.0000000000000","11.0000000000000","12.0000000000000","13.0000000000000","14.0000000000000","15.0000000000000","16.0000000000000","17.0000000000000","18.0000000000000","19.0000000000000","20.0000000000000","21.0000000000000","22.0000000000000","23.0000000000000","24.0000000000000","25.0000000000000","26.0000000000000","27.0000000000000","28.0000000000000","29.0000000000000","30.0000000000000","31.0000000000000","32.0000000000000","33.0000000000000","34.0000000000000","35.0000000000000","36.0000000000000","37.0000000000000","38.0000000000000","39.0000000000000","40.0000000000000","41.0000000000000","42.0000000000000","43.0000000000000","44.0000000000000","45.0000000000000","46.0000000000000","47.0000000000000","48.0000000000000","49.0000000000000","50.0000000000000","51.0000000000000","52.0000000000000","53.0000000000000","54.0000000000000","55.0000000000000","56.0000000000000","57.0000000000000","58.0000000000000","59.0000000000000","60.0000000000000","61.0000000000000","62.0000000000000","63.0000000000000","64.0000000000000","65.0000000000000","66.0000000000000","67.0000000000000","68.0000000000000","69.0000000000000","70.0000000000000","71.0000000000000","72.0000000000000","73.0000000000000","74.0000000000000","75.0000000000000","76.0000000000000","77.0000000000000","78.0000000000000","79.0000000000000","80.0000000000000","81.0000000000000","82.0000000000000","83.0000000000000","84.0000000000000","85.0000000000000","86.0000000000000","87.0000000000000","88.0000000000000","89.0000000000000","90.0000000000000","91.0000000000000","92.0000000000000","93.0000000000000","94.0000000000000","95.0000000000000","96.0000000000000","97.0000000000000","98.0000000000000","99.0000000000000","100.000000000000"],"var":"x_range","width":null}],"flicker":false,"id":"60280919-e556-4e30-885d-89608507b1a3","layout":[[["a_b",12,null]],[["lambda_",12,null]],[["x_range",12,null]],[["",12,null]]],"style":"None"}}︡{"interact":{"controls":[{"animate":true,"control_type":"range-slider","default":[9,11],"display_value":true,"label":"[a, b]: ","vals":["-10.0000000000000","-9.00000000000000","-8.00000000000000","-7.00000000000000","-6.00000000000000","-5.00000000000000","-4.00000000000000","-3.00000000000000","-2.00000000000000","-1.00000000000000","0.000000000000000","1.00000000000000","2.00000000000000","3.00000000000000","4.00000000000000","5.00000000000000","6.00000000000000","7.00000000000000","8.00000000000000","9.00000000000000","10.0000000000000"],"var":"a_b","width":null},{"animate":true,"control_type":"slider","default":240,"display_value":true,"label":"λ: ","vals":["0.0100000000000000","0.0110000000000000","0.0120000000000000","0.0130000000000000","0.0140000000000000","0.0150000000000000","0.0160000000000000","0.0170000000000000","0.0180000000000000","0.0190000000000000","0.0200000000000000","0.0210000000000000","0.0220000000000000","0.0230000000000000","0.0240000000000000","0.0250000000000000","0.0260000000000000","0.0270000000000000","0.0280000000000000","0.0290000000000000","0.0300000000000000","0.0310000000000000","0.0320000000000000","0.0330000000000000","0.0340000000000000","0.0350000000000000","0.0360000000000000","0.0370000000000000","0.0380000000000000","0.0390000000000000","0.0400000000000000","0.0410000000000000","0.0420000000000000","0.0430000000000000","0.0440000000000000","0.0450000000000000","0.0460000000000000","0.0470000000000000","0.0480000000000000","0.0490000000000000","0.0500000000000000","0.0510000000000000","0.0520000000000000","0.0530000000000000","0.0540000000000000","0.0550000000000000","0.0560000000000000","0.0570000000000000","0.0580000000000000","0.0590000000000000","0.0600000000000000","0.0610000000000000","0.0620000000000000","0.0630000000000000","0.0640000000000000","0.0650000000000000","0.0660000000000000","0.0670000000000000","0.0680000000000000","0.0690000000000000","0.0700000000000000","0.0710000000000000","0.0720000000000001","0.0730000000000001","0.0740000000000001","0.0750000000000001","0.0760000000000001","0.0770000000000001","0.0780000000000001","0.0790000000000001","0.0800000000000001","0.0810000000000001","0.0820000000000001","0.0830000000000001","0.0840000000000001","0.0850000000000001","0.0860000000000001","0.0870000000000001","0.0880000000000001","0.0890000000000001","0.0900000000000001","0.0910000000000001","0.0920000000000001","0.0930000000000001","0.0940000000000001","0.0950000000000001","0.0960000000000001","0.0970000000000001","0.0980000000000001","0.0990000000000001","0.100000000000000","0.101000000000000","0.102000000000000","0.103000000000000","0.104000000000000","0.105000000000000","0.106000000000000","0.107000000000000","0.108000000000000","0.109000000000000","0.110000000000000","0.111000000000000","0.112000000000000","0.113000000000000","0.114000000000000","0.115000000000000","0.116000000000000","0.117000000000000","0.118000000000000","0.119000000000000","0.120000000000000","0.121000000000000","0.122000000000000","0.123000000000000","0.124000000000000","0.125000000000000","0.126000000000000","0.127000000000000","0.128000000000000","0.129000000000000","0.130000000000000","0.131000000000000","0.132000000000000","0.133000000000000","0.134000000000000","0.135000000000000","0.136000000000000","0.137000000000000","0.138000000000000","0.139000000000000","0.140000000000000","0.141000000000000","0.142000000000000","0.143000000000000","0.144000000000000","0.145000000000000","0.146000000000000","0.147000000000000","0.148000000000000","0.149000000000000","0.150000000000000","0.151000000000000","0.152000000000000","0.153000000000000","0.154000000000000","0.155000000000000","0.156000000000000","0.157000000000000","0.158000000000000","0.159000000000000","0.160000000000000","0.161000000000000","0.162000000000000","0.163000000000000","0.164000000000000","0.165000000000000","0.166000000000000","0.167000000000000","0.168000000000000","0.169000000000000","0.170000000000000","0.171000000000000","0.172000000000000","0.173000000000000","0.174000000000000","0.175000000000000","0.176000000000000","0.177000000000000","0.178000000000000","0.179000000000000","0.180000000000000","0.181000000000000","0.182000000000000","0.183000000000000","0.184000000000000","0.185000000000000","0.186000000000000","0.187000000000000","0.188000000000000","0.189000000000000","0.190000000000000","0.191000000000000","0.192000000000000","0.193000000000000","0.194000000000000","0.195000000000000","0.196000000000000","0.197000000000000","0.198000000000000","0.199000000000000","0.200000000000000","0.201000000000000","0.202000000000000","0.203000000000000","0.204000000000000","0.205000000000000","0.206000000000000","0.207000000000000","0.208000000000000","0.209000000000000","0.210000000000000","0.211000000000000","0.212000000000000","0.213000000000000","0.214000000000000","0.215000000000000","0.216000000000000","0.217000000000000","0.218000000000000","0.219000000000000","0.220000000000000","0.221000000000000","0.222000000000000","0.223000000000000","0.224000000000000","0.225000000000000","0.226000000000000","0.227000000000000","0.228000000000000","0.229000000000000","0.230000000000000","0.231000000000000","0.232000000000000","0.233000000000000","0.234000000000000","0.235000000000000","0.236000000000000","0.237000000000000","0.238000000000000","0.239000000000000","0.240000000000000","0.241000000000000","0.242000000000000","0.243000000000000","0.244000000000000","0.245000000000000","0.246000000000000","0.247000000000000","0.248000000000000","0.249000000000000","0.250000000000000","0.251000000000000","0.252000000000000","0.253000000000000","0.254000000000000","0.255000000000000","0.256000000000000","0.257000000000000","0.258000000000000","0.259000000000000","0.260000000000000","0.261000000000000","0.262000000000000","0.263000000000000","0.264000000000000","0.265000000000000","0.266000000000000","0.267000000000000","0.268000000000000","0.269000000000000","0.270000000000000","0.271000000000000","0.272000000000000","0.273000000000000","0.274000000000000","0.275000000000000","0.276000000000000","0.277000000000000","0.278000000000000","0.279000000000000","0.280000000000000","0.281000000000000","0.282000000000000","0.283000000000000","0.284000000000000","0.285000000000000","0.286000000000000","0.287000000000000","0.288000000000000","0.289000000000000","0.290000000000000","0.291000000000000","0.292000000000000","0.293000000000000","0.294000000000000","0.295000000000000","0.296000000000000","0.297000000000000","0.298000000000000","0.299000000000000","0.300000000000000","0.301000000000000","0.302000000000000","0.303000000000000","0.304000000000000","0.305000000000000","0.306000000000000","0.307000000000000","0.308000000000000","0.309000000000000","0.310000000000000","0.311000000000000","0.312000000000000","0.313000000000000","0.314000000000000","0.315000000000000","0.316000000000000","0.317000000000000","0.318000000000000","0.319000000000000","0.320000000000000","0.321000000000000","0.322000000000000","0.323000000000000","0.324000000000000","0.325000000000000","0.326000000000000","0.327000000000000","0.328000000000000","0.329000000000000","0.330000000000000","0.331000000000000","0.332000000000000","0.333000000000000","0.334000000000000","0.335000000000000","0.336000000000000","0.337000000000000","0.338000000000000","0.339000000000000","0.340000000000000","0.341000000000000","0.342000000000000","0.343000000000000","0.344000000000000","0.345000000000000","0.346000000000000","0.347000000000000","0.348000000000000","0.349000000000000","0.350000000000000","0.351000000000000","0.352000000000000","0.353000000000000","0.354000000000000","0.355000000000000","0.356000000000000","0.357000000000000","0.358000000000000","0.359000000000000","0.360000000000000","0.361000000000000","0.362000000000000","0.363000000000000","0.364000000000000","0.365000000000000","0.366000000000000","0.367000000000000","0.368000000000000","0.369000000000000","0.370000000000000","0.371000000000000","0.372000000000000","0.373000000000000","0.374000000000000","0.375000000000000","0.376000000000000","0.377000000000000","0.378000000000000","0.379000000000000","0.380000000000000","0.381000000000000","0.382000000000000","0.383000000000000","0.384000000000000","0.385000000000000","0.386000000000000","0.387000000000000","0.388000000000000","0.389000000000000","0.390000000000000","0.391000000000000","0.392000000000000","0.393000000000000","0.394000000000000","0.395000000000000","0.396000000000000","0.397000000000000","0.398000000000000","0.399000000000000","0.400000000000000","0.401000000000000","0.402000000000000","0.403000000000000","0.404000000000000","0.405000000000000","0.406000000000000","0.407000000000000","0.408000000000000","0.409000000000000","0.410000000000000","0.411000000000000","0.412000000000000","0.413000000000000","0.414000000000000","0.415000000000000","0.416000000000000","0.417000000000000","0.418000000000000","0.419000000000000","0.420000000000000","0.421000000000000","0.422000000000000","0.423000000000000","0.424000000000000","0.425000000000000","0.426000000000000","0.427000000000000","0.428000000000000","0.429000000000000","0.430000000000000","0.431000000000000","0.432000000000000","0.433000000000000","0.434000000000000","0.435000000000000","0.436000000000000","0.437000000000000","0.438000000000000","0.439000000000000","0.440000000000000","0.441000000000000","0.442000000000000","0.443000000000000","0.444000000000000","0.445000000000000","0.446000000000000","0.447000000000000","0.448000000000000","0.449000000000000","0.450000000000000","0.451000000000000","0.452000000000000","0.453000000000000","0.454000000000000","0.455000000000000","0.456000000000000","0.457000000000000","0.458000000000000","0.459000000000000","0.460000000000000","0.461000000000000","0.462000000000000","0.463000000000000","0.464000000000000","0.465000000000000","0.466000000000000","0.467000000000000","0.468000000000000","0.469000000000000","0.470000000000000","0.471000000000000","0.472000000000000","0.473000000000000","0.474000000000000","0.475000000000000","0.476000000000000","0.477000000000000","0.478000000000000","0.479000000000000","0.480000000000000","0.481000000000000","0.482000000000000","0.483000000000000","0.484000000000000","0.485000000000000","0.486000000000000","0.487000000000000","0.488000000000000","0.489000000000000","0.490000000000000","0.491000000000000","0.492000000000000","0.493000000000000","0.494000000000000","0.495000000000000","0.496000000000000","0.497000000000000","0.498000000000000","0.499000000000000","0.500000000000000","0.501000000000000","0.502000000000000","0.503000000000000","0.504000000000000","0.505000000000000","0.506000000000000","0.507000000000000","0.508000000000000","0.509000000000000","0.510000000000000","0.511000000000000","0.512000000000000","0.513000000000000","0.514000000000000","0.515000000000000","0.516000000000000","0.517000000000000","0.518000000000000","0.519000000000000","0.520000000000000","0.521000000000000","0.522000000000000","0.523000000000000","0.524000000000000","0.525000000000000","0.526000000000000","0.527000000000000","0.528000000000000","0.529000000000000","0.530000000000000","0.531000000000000","0.532000000000000","0.533000000000000","0.534000000000000","0.535000000000000","0.536000000000000","0.537000000000000","0.538000000000000","0.539000000000000","0.540000000000000","0.541000000000000","0.542000000000000","0.543000000000000","0.544000000000000","0.545000000000000","0.546000000000000","0.547000000000000","0.548000000000000","0.549000000000000","0.550000000000000","0.551000000000000","0.552000000000000","0.553000000000000","0.554000000000000","0.555000000000000","0.556000000000000","0.557000000000000","0.558000000000000","0.559000000000000","0.560000000000000","0.561000000000000","0.562000000000000","0.563000000000000","0.564000000000000","0.565000000000000","0.566000000000000","0.567000000000000","0.568000000000000","0.569000000000000","0.570000000000000","0.571000000000000","0.572000000000000","0.573000000000000","0.574000000000000","0.575000000000000","0.576000000000000","0.577000000000000","0.578000000000000","0.579000000000000","0.580000000000000","0.581000000000000","0.582000000000000","0.583000000000000","0.584000000000000","0.585000000000000","0.586000000000000","0.587000000000000","0.588000000000000","0.589000000000000","0.590000000000000","0.591000000000000","0.592000000000000","0.593000000000000","0.594000000000000","0.595000000000000","0.596000000000000","0.597000000000000","0.598000000000000","0.599000000000000","0.600000000000000","0.601000000000000","0.602000000000000","0.603000000000000","0.604000000000000","0.605000000000000","0.606000000000000","0.607000000000000","0.608000000000000","0.609000000000000","0.610000000000000","0.611000000000000","0.612000000000000","0.613000000000000","0.614000000000000","0.615000000000000","0.616000000000000","0.617000000000000","0.618000000000000","0.619000000000000","0.620000000000000","0.621000000000000","0.622000000000000","0.623000000000000","0.624000000000000","0.625000000000000","0.626000000000000","0.627000000000000","0.628000000000000","0.629000000000000","0.630000000000000","0.631000000000000","0.632000000000000","0.633000000000000","0.634000000000000","0.635000000000000","0.636000000000000","0.637000000000000","0.638000000000000","0.639000000000000","0.640000000000000","0.641000000000000","0.642000000000000","0.643000000000000","0.644000000000000","0.645000000000000","0.646000000000000","0.647000000000000","0.648000000000000","0.649000000000000","0.650000000000000","0.651000000000000","0.652000000000000","0.653000000000000","0.654000000000000","0.655000000000000","0.656000000000000","0.657000000000000","0.658000000000000","0.659000000000000","0.660000000000000","0.661000000000000","0.662000000000000","0.663000000000000","0.664000000000000","0.665000000000000","0.666000000000000","0.667000000000000","0.668000000000000","0.669000000000000","0.670000000000000","0.671000000000000","0.672000000000000","0.673000000000000","0.674000000000000","0.675000000000000","0.676000000000000","0.677000000000000","0.678000000000000","0.679000000000000","0.680000000000000","0.681000000000000","0.682000000000000","0.683000000000000","0.684000000000000","0.685000000000000","0.686000000000000","0.687000000000000","0.688000000000001","0.689000000000001","0.690000000000001","0.691000000000001","0.692000000000001","0.693000000000001","0.694000000000001","0.695000000000001","0.696000000000001","0.697000000000001","0.698000000000001","0.699000000000001","0.700000000000001","0.701000000000001","0.702000000000001","0.703000000000001","0.704000000000001","0.705000000000001","0.706000000000001","0.707000000000001","0.708000000000001","0.709000000000001","0.710000000000001","0.711000000000001","0.712000000000001","0.713000000000001","0.714000000000001","0.715000000000001","0.716000000000001","0.717000000000001","0.718000000000001","0.719000000000001","0.720000000000001","0.721000000000001","0.722000000000001","0.723000000000001","0.724000000000001","0.725000000000001","0.726000000000001","0.727000000000001","0.728000000000001","0.729000000000001","0.730000000000001","0.731000000000001","0.732000000000001","0.733000000000001","0.734000000000001","0.735000000000001","0.736000000000001","0.737000000000001","0.738000000000001","0.739000000000001","0.740000000000001","0.741000000000001","0.742000000000001","0.743000000000001","0.744000000000001","0.745000000000001","0.746000000000001","0.747000000000001","0.748000000000001","0.749000000000001","0.750000000000001","0.751000000000001","0.752000000000001","0.753000000000001","0.754000000000001","0.755000000000001","0.756000000000001","0.757000000000001","0.758000000000001","0.759000000000001","0.760000000000001","0.761000000000001","0.762000000000001","0.763000000000001","0.764000000000001","0.765000000000001","0.766000000000001","0.767000000000001","0.768000000000001","0.769000000000001","0.770000000000001","0.771000000000001","0.772000000000001","0.773000000000001","0.774000000000001","0.775000000000001","0.776000000000001","0.777000000000001","0.778000000000001","0.779000000000001","0.780000000000001","0.781000000000001","0.782000000000001","0.783000000000001","0.784000000000001","0.785000000000001","0.786000000000001","0.787000000000001","0.788000000000001","0.789000000000001","0.790000000000001","0.791000000000001","0.792000000000001","0.793000000000001","0.794000000000001","0.795000000000001","0.796000000000001","0.797000000000001","0.798000000000001","0.799000000000001","0.800000000000001","0.801000000000001","0.802000000000001","0.803000000000001","0.804000000000001","0.805000000000001","0.806000000000001","0.807000000000001","0.808000000000001","0.809000000000001","0.810000000000001","0.811000000000001","0.812000000000001","0.813000000000001","0.814000000000001","0.815000000000001","0.816000000000001","0.817000000000001","0.818000000000001","0.819000000000001","0.820000000000001","0.821000000000001","0.822000000000001","0.823000000000001","0.824000000000001","0.825000000000001","0.826000000000001","0.827000000000001","0.828000000000001","0.829000000000001","0.830000000000001","0.831000000000001","0.832000000000001","0.833000000000001","0.834000000000001","0.835000000000001","0.836000000000001","0.837000000000001","0.838000000000001","0.839000000000001","0.840000000000001","0.841000000000001","0.842000000000001","0.843000000000001","0.844000000000001","0.845000000000001","0.846000000000001","0.847000000000001","0.848000000000001","0.849000000000001","0.850000000000001","0.851000000000001","0.852000000000001","0.853000000000001","0.854000000000001","0.855000000000001","0.856000000000001","0.857000000000001","0.858000000000001","0.859000000000001","0.860000000000001","0.861000000000001","0.862000000000001","0.863000000000001","0.864000000000001","0.865000000000001","0.866000000000001","0.867000000000001","0.868000000000001","0.869000000000001","0.870000000000001","0.871000000000001","0.872000000000001","0.873000000000001","0.874000000000001","0.875000000000001","0.876000000000001","0.877000000000001","0.878000000000001","0.879000000000001","0.880000000000001","0.881000000000001","0.882000000000001","0.883000000000001","0.884000000000001","0.885000000000001","0.886000000000001","0.887000000000001","0.888000000000001","0.889000000000001","0.890000000000001","0.891000000000001","0.892000000000001","0.893000000000001","0.894000000000001","0.895000000000001","0.896000000000001","0.897000000000001","0.898000000000001","0.899000000000001","0.900000000000001","0.901000000000001","0.902000000000001","0.903000000000001","0.904000000000001","0.905000000000001","0.906000000000001","0.907000000000001","0.908000000000001","0.909000000000001","0.910000000000001","0.911000000000001","0.912000000000001","0.913000000000001","0.914000000000001","0.915000000000001","0.916000000000001","0.917000000000001","0.918000000000001","0.919000000000001","0.920000000000001","0.921000000000001","0.922000000000001","0.923000000000001","0.924000000000001","0.925000000000001","0.926000000000001","0.927000000000001","0.928000000000001","0.929000000000001","0.930000000000001","0.931000000000001","0.932000000000001","0.933000000000001","0.934000000000001","0.935000000000001","0.936000000000001","0.937000000000001","0.938000000000001","0.939000000000001","0.940000000000001","0.941000000000001","0.942000000000001","0.943000000000001","0.944000000000001","0.945000000000001","0.946000000000001","0.947000000000001","0.948000000000001","0.949000000000001","0.950000000000001","0.951000000000001","0.952000000000001","0.953000000000001","0.954000000000001","0.955000000000001","0.956000000000001","0.957000000000001","0.958000000000001","0.959000000000001","0.960000000000001","0.961000000000001","0.962000000000001","0.963000000000001","0.964000000000001","0.965000000000001","0.966000000000001","0.967000000000001","0.968000000000001","0.969000000000001","0.970000000000001","0.971000000000001","0.972000000000001","0.973000000000001","0.974000000000001","0.975000000000001","0.976000000000001","0.977000000000001","0.978000000000001","0.979000000000001","0.980000000000001","0.981000000000001","0.982000000000001","0.983000000000001","0.984000000000001","0.985000000000001","0.986000000000001","0.987000000000001","0.988000000000001","0.989000000000001","0.990000000000001","0.991000000000001","0.992000000000001","0.993000000000001","0.994000000000001","0.995000000000001","0.996000000000001","0.997000000000001","0.998000000000001","0.999000000000001","1.00000000000000"],"var":"lambda_","width":null},{"control_type":"input-box","default":0,"label":"t: ","nrows":1,"readonly":false,"submit_button":null,"type":null,"var":"t","width":null}],"flicker":false,"id":"352708bf-fdb8-445a-8ac6-a4a9a5a6e037","layout":[[["a_b",12,null]],[["lambda_",12,null]],[["t",12,null]],[["",12,null]]],"style":"None"}}︡{"interact":{"controls":[{"animate":true,"control_type":"range-slider","default":[9,11],"display_value":true,"label":"[a, b]: ","vals":["-10.0000000000000","-9.00000000000000","-8.00000000000000","-7.00000000000000","-6.00000000000000","-5.00000000000000","-4.00000000000000","-3.00000000000000","-2.00000000000000","-1.00000000000000","0.000000000000000","1.00000000000000","2.00000000000000","3.00000000000000","4.00000000000000","5.00000000000000","6.00000000000000","7.00000000000000","8.00000000000000","9.00000000000000","10.0000000000000"],"var":"a_b","width":null},{"animate":true,"control_type":"slider","default":240,"display_value":true,"label":"λ: ","vals":["0.0100000000000000","0.0110000000000000","0.0120000000000000","0.0130000000000000","0.0140000000000000","0.0150000000000000","0.0160000000000000","0.0170000000000000","0.0180000000000000","0.0190000000000000","0.0200000000000000","0.0210000000000000","0.0220000000000000","0.0230000000000000","0.0240000000000000","0.0250000000000000","0.0260000000000000","0.0270000000000000","0.0280000000000000","0.0290000000000000","0.0300000000000000","0.0310000000000000","0.0320000000000000","0.0330000000000000","0.0340000000000000","0.0350000000000000","0.0360000000000000","0.0370000000000000","0.0380000000000000","0.0390000000000000","0.0400000000000000","0.0410000000000000","0.0420000000000000","0.0430000000000000","0.0440000000000000","0.0450000000000000","0.0460000000000000","0.0470000000000000","0.0480000000000000","0.0490000000000000","0.0500000000000000","0.0510000000000000","0.0520000000000000","0.0530000000000000","0.0540000000000000","0.0550000000000000","0.0560000000000000","0.0570000000000000","0.0580000000000000","0.0590000000000000","0.0600000000000000","0.0610000000000000","0.0620000000000000","0.0630000000000000","0.0640000000000000","0.0650000000000000","0.0660000000000000","0.0670000000000000","0.0680000000000000","0.0690000000000000","0.0700000000000000","0.0710000000000000","0.0720000000000001","0.0730000000000001","0.0740000000000001","0.0750000000000001","0.0760000000000001","0.0770000000000001","0.0780000000000001","0.0790000000000001","0.0800000000000001","0.0810000000000001","0.0820000000000001","0.0830000000000001","0.0840000000000001","0.0850000000000001","0.0860000000000001","0.0870000000000001","0.0880000000000001","0.0890000000000001","0.0900000000000001","0.0910000000000001","0.0920000000000001","0.0930000000000001","0.0940000000000001","0.0950000000000001","0.0960000000000001","0.0970000000000001","0.0980000000000001","0.0990000000000001","0.100000000000000","0.101000000000000","0.102000000000000","0.103000000000000","0.104000000000000","0.105000000000000","0.106000000000000","0.107000000000000","0.108000000000000","0.109000000000000","0.110000000000000","0.111000000000000","0.112000000000000","0.113000000000000","0.114000000000000","0.115000000000000","0.116000000000000","0.117000000000000","0.118000000000000","0.119000000000000","0.120000000000000","0.121000000000000","0.122000000000000","0.123000000000000","0.124000000000000","0.125000000000000","0.126000000000000","0.127000000000000","0.128000000000000","0.129000000000000","0.130000000000000","0.131000000000000","0.132000000000000","0.133000000000000","0.134000000000000","0.135000000000000","0.136000000000000","0.137000000000000","0.138000000000000","0.139000000000000","0.140000000000000","0.141000000000000","0.142000000000000","0.143000000000000","0.144000000000000","0.145000000000000","0.146000000000000","0.147000000000000","0.148000000000000","0.149000000000000","0.150000000000000","0.151000000000000","0.152000000000000","0.153000000000000","0.154000000000000","0.155000000000000","0.156000000000000","0.157000000000000","0.158000000000000","0.159000000000000","0.160000000000000","0.161000000000000","0.162000000000000","0.163000000000000","0.164000000000000","0.165000000000000","0.166000000000000","0.167000000000000","0.168000000000000","0.169000000000000","0.170000000000000","0.171000000000000","0.172000000000000","0.173000000000000","0.174000000000000","0.175000000000000","0.176000000000000","0.177000000000000","0.178000000000000","0.179000000000000","0.180000000000000","0.181000000000000","0.182000000000000","0.183000000000000","0.184000000000000","0.185000000000000","0.186000000000000","0.187000000000000","0.188000000000000","0.189000000000000","0.190000000000000","0.191000000000000","0.192000000000000","0.193000000000000","0.194000000000000","0.195000000000000","0.196000000000000","0.197000000000000","0.198000000000000","0.199000000000000","0.200000000000000","0.201000000000000","0.202000000000000","0.203000000000000","0.204000000000000","0.205000000000000","0.206000000000000","0.207000000000000","0.208000000000000","0.209000000000000","0.210000000000000","0.211000000000000","0.212000000000000","0.213000000000000","0.214000000000000","0.215000000000000","0.216000000000000","0.217000000000000","0.218000000000000","0.219000000000000","0.220000000000000","0.221000000000000","0.222000000000000","0.223000000000000","0.224000000000000","0.225000000000000","0.226000000000000","0.227000000000000","0.228000000000000","0.229000000000000","0.230000000000000","0.231000000000000","0.232000000000000","0.233000000000000","0.234000000000000","0.235000000000000","0.236000000000000","0.237000000000000","0.238000000000000","0.239000000000000","0.240000000000000","0.241000000000000","0.242000000000000","0.243000000000000","0.244000000000000","0.245000000000000","0.246000000000000","0.247000000000000","0.248000000000000","0.249000000000000","0.250000000000000","0.251000000000000","0.252000000000000","0.253000000000000","0.254000000000000","0.255000000000000","0.256000000000000","0.257000000000000","0.258000000000000","0.259000000000000","0.260000000000000","0.261000000000000","0.262000000000000","0.263000000000000","0.264000000000000","0.265000000000000","0.266000000000000","0.267000000000000","0.268000000000000","0.269000000000000","0.270000000000000","0.271000000000000","0.272000000000000","0.273000000000000","0.274000000000000","0.275000000000000","0.276000000000000","0.277000000000000","0.278000000000000","0.279000000000000","0.280000000000000","0.281000000000000","0.282000000000000","0.283000000000000","0.284000000000000","0.285000000000000","0.286000000000000","0.287000000000000","0.288000000000000","0.289000000000000","0.290000000000000","0.291000000000000","0.292000000000000","0.293000000000000","0.294000000000000","0.295000000000000","0.296000000000000","0.297000000000000","0.298000000000000","0.299000000000000","0.300000000000000","0.301000000000000","0.302000000000000","0.303000000000000","0.304000000000000","0.305000000000000","0.306000000000000","0.307000000000000","0.308000000000000","0.309000000000000","0.310000000000000","0.311000000000000","0.312000000000000","0.313000000000000","0.314000000000000","0.315000000000000","0.316000000000000","0.317000000000000","0.318000000000000","0.319000000000000","0.320000000000000","0.321000000000000","0.322000000000000","0.323000000000000","0.324000000000000","0.325000000000000","0.326000000000000","0.327000000000000","0.328000000000000","0.329000000000000","0.330000000000000","0.331000000000000","0.332000000000000","0.333000000000000","0.334000000000000","0.335000000000000","0.336000000000000","0.337000000000000","0.338000000000000","0.339000000000000","0.340000000000000","0.341000000000000","0.342000000000000","0.343000000000000","0.344000000000000","0.345000000000000","0.346000000000000","0.347000000000000","0.348000000000000","0.349000000000000","0.350000000000000","0.351000000000000","0.352000000000000","0.353000000000000","0.354000000000000","0.355000000000000","0.356000000000000","0.357000000000000","0.358000000000000","0.359000000000000","0.360000000000000","0.361000000000000","0.362000000000000","0.363000000000000","0.364000000000000","0.365000000000000","0.366000000000000","0.367000000000000","0.368000000000000","0.369000000000000","0.370000000000000","0.371000000000000","0.372000000000000","0.373000000000000","0.374000000000000","0.375000000000000","0.376000000000000","0.377000000000000","0.378000000000000","0.379000000000000","0.380000000000000","0.381000000000000","0.382000000000000","0.383000000000000","0.384000000000000","0.385000000000000","0.386000000000000","0.387000000000000","0.388000000000000","0.389000000000000","0.390000000000000","0.391000000000000","0.392000000000000","0.393000000000000","0.394000000000000","0.395000000000000","0.396000000000000","0.397000000000000","0.398000000000000","0.399000000000000","0.400000000000000","0.401000000000000","0.402000000000000","0.403000000000000","0.404000000000000","0.405000000000000","0.406000000000000","0.407000000000000","0.408000000000000","0.409000000000000","0.410000000000000","0.411000000000000","0.412000000000000","0.413000000000000","0.414000000000000","0.415000000000000","0.416000000000000","0.417000000000000","0.418000000000000","0.419000000000000","0.420000000000000","0.421000000000000","0.422000000000000","0.423000000000000","0.424000000000000","0.425000000000000","0.426000000000000","0.427000000000000","0.428000000000000","0.429000000000000","0.430000000000000","0.431000000000000","0.432000000000000","0.433000000000000","0.434000000000000","0.435000000000000","0.436000000000000","0.437000000000000","0.438000000000000","0.439000000000000","0.440000000000000","0.441000000000000","0.442000000000000","0.443000000000000","0.444000000000000","0.445000000000000","0.446000000000000","0.447000000000000","0.448000000000000","0.449000000000000","0.450000000000000","0.451000000000000","0.452000000000000","0.453000000000000","0.454000000000000","0.455000000000000","0.456000000000000","0.457000000000000","0.458000000000000","0.459000000000000","0.460000000000000","0.461000000000000","0.462000000000000","0.463000000000000","0.464000000000000","0.465000000000000","0.466000000000000","0.467000000000000","0.468000000000000","0.469000000000000","0.470000000000000","0.471000000000000","0.472000000000000","0.473000000000000","0.474000000000000","0.475000000000000","0.476000000000000","0.477000000000000","0.478000000000000","0.479000000000000","0.480000000000000","0.481000000000000","0.482000000000000","0.483000000000000","0.484000000000000","0.485000000000000","0.486000000000000","0.487000000000000","0.488000000000000","0.489000000000000","0.490000000000000","0.491000000000000","0.492000000000000","0.493000000000000","0.494000000000000","0.495000000000000","0.496000000000000","0.497000000000000","0.498000000000000","0.499000000000000","0.500000000000000","0.501000000000000","0.502000000000000","0.503000000000000","0.504000000000000","0.505000000000000","0.506000000000000","0.507000000000000","0.508000000000000","0.509000000000000","0.510000000000000","0.511000000000000","0.512000000000000","0.513000000000000","0.514000000000000","0.515000000000000","0.516000000000000","0.517000000000000","0.518000000000000","0.519000000000000","0.520000000000000","0.521000000000000","0.522000000000000","0.523000000000000","0.524000000000000","0.525000000000000","0.526000000000000","0.527000000000000","0.528000000000000","0.529000000000000","0.530000000000000","0.531000000000000","0.532000000000000","0.533000000000000","0.534000000000000","0.535000000000000","0.536000000000000","0.537000000000000","0.538000000000000","0.539000000000000","0.540000000000000","0.541000000000000","0.542000000000000","0.543000000000000","0.544000000000000","0.545000000000000","0.546000000000000","0.547000000000000","0.548000000000000","0.549000000000000","0.550000000000000","0.551000000000000","0.552000000000000","0.553000000000000","0.554000000000000","0.555000000000000","0.556000000000000","0.557000000000000","0.558000000000000","0.559000000000000","0.560000000000000","0.561000000000000","0.562000000000000","0.563000000000000","0.564000000000000","0.565000000000000","0.566000000000000","0.567000000000000","0.568000000000000","0.569000000000000","0.570000000000000","0.571000000000000","0.572000000000000","0.573000000000000","0.574000000000000","0.575000000000000","0.576000000000000","0.577000000000000","0.578000000000000","0.579000000000000","0.580000000000000","0.581000000000000","0.582000000000000","0.583000000000000","0.584000000000000","0.585000000000000","0.586000000000000","0.587000000000000","0.588000000000000","0.589000000000000","0.590000000000000","0.591000000000000","0.592000000000000","0.593000000000000","0.594000000000000","0.595000000000000","0.596000000000000","0.597000000000000","0.598000000000000","0.599000000000000","0.600000000000000","0.601000000000000","0.602000000000000","0.603000000000000","0.604000000000000","0.605000000000000","0.606000000000000","0.607000000000000","0.608000000000000","0.609000000000000","0.610000000000000","0.611000000000000","0.612000000000000","0.613000000000000","0.614000000000000","0.615000000000000","0.616000000000000","0.617000000000000","0.618000000000000","0.619000000000000","0.620000000000000","0.621000000000000","0.622000000000000","0.623000000000000","0.624000000000000","0.625000000000000","0.626000000000000","0.627000000000000","0.628000000000000","0.629000000000000","0.630000000000000","0.631000000000000","0.632000000000000","0.633000000000000","0.634000000000000","0.635000000000000","0.636000000000000","0.637000000000000","0.638000000000000","0.639000000000000","0.640000000000000","0.641000000000000","0.642000000000000","0.643000000000000","0.644000000000000","0.645000000000000","0.646000000000000","0.647000000000000","0.648000000000000","0.649000000000000","0.650000000000000","0.651000000000000","0.652000000000000","0.653000000000000","0.654000000000000","0.655000000000000","0.656000000000000","0.657000000000000","0.658000000000000","0.659000000000000","0.660000000000000","0.661000000000000","0.662000000000000","0.663000000000000","0.664000000000000","0.665000000000000","0.666000000000000","0.667000000000000","0.668000000000000","0.669000000000000","0.670000000000000","0.671000000000000","0.672000000000000","0.673000000000000","0.674000000000000","0.675000000000000","0.676000000000000","0.677000000000000","0.678000000000000","0.679000000000000","0.680000000000000","0.681000000000000","0.682000000000000","0.683000000000000","0.684000000000000","0.685000000000000","0.686000000000000","0.687000000000000","0.688000000000001","0.689000000000001","0.690000000000001","0.691000000000001","0.692000000000001","0.693000000000001","0.694000000000001","0.695000000000001","0.696000000000001","0.697000000000001","0.698000000000001","0.699000000000001","0.700000000000001","0.701000000000001","0.702000000000001","0.703000000000001","0.704000000000001","0.705000000000001","0.706000000000001","0.707000000000001","0.708000000000001","0.709000000000001","0.710000000000001","0.711000000000001","0.712000000000001","0.713000000000001","0.714000000000001","0.715000000000001","0.716000000000001","0.717000000000001","0.718000000000001","0.719000000000001","0.720000000000001","0.721000000000001","0.722000000000001","0.723000000000001","0.724000000000001","0.725000000000001","0.726000000000001","0.727000000000001","0.728000000000001","0.729000000000001","0.730000000000001","0.731000000000001","0.732000000000001","0.733000000000001","0.734000000000001","0.735000000000001","0.736000000000001","0.737000000000001","0.738000000000001","0.739000000000001","0.740000000000001","0.741000000000001","0.742000000000001","0.743000000000001","0.744000000000001","0.745000000000001","0.746000000000001","0.747000000000001","0.748000000000001","0.749000000000001","0.750000000000001","0.751000000000001","0.752000000000001","0.753000000000001","0.754000000000001","0.755000000000001","0.756000000000001","0.757000000000001","0.758000000000001","0.759000000000001","0.760000000000001","0.761000000000001","0.762000000000001","0.763000000000001","0.764000000000001","0.765000000000001","0.766000000000001","0.767000000000001","0.768000000000001","0.769000000000001","0.770000000000001","0.771000000000001","0.772000000000001","0.773000000000001","0.774000000000001","0.775000000000001","0.776000000000001","0.777000000000001","0.778000000000001","0.779000000000001","0.780000000000001","0.781000000000001","0.782000000000001","0.783000000000001","0.784000000000001","0.785000000000001","0.786000000000001","0.787000000000001","0.788000000000001","0.789000000000001","0.790000000000001","0.791000000000001","0.792000000000001","0.793000000000001","0.794000000000001","0.795000000000001","0.796000000000001","0.797000000000001","0.798000000000001","0.799000000000001","0.800000000000001","0.801000000000001","0.802000000000001","0.803000000000001","0.804000000000001","0.805000000000001","0.806000000000001","0.807000000000001","0.808000000000001","0.809000000000001","0.810000000000001","0.811000000000001","0.812000000000001","0.813000000000001","0.814000000000001","0.815000000000001","0.816000000000001","0.817000000000001","0.818000000000001","0.819000000000001","0.820000000000001","0.821000000000001","0.822000000000001","0.823000000000001","0.824000000000001","0.825000000000001","0.826000000000001","0.827000000000001","0.828000000000001","0.829000000000001","0.830000000000001","0.831000000000001","0.832000000000001","0.833000000000001","0.834000000000001","0.835000000000001","0.836000000000001","0.837000000000001","0.838000000000001","0.839000000000001","0.840000000000001","0.841000000000001","0.842000000000001","0.843000000000001","0.844000000000001","0.845000000000001","0.846000000000001","0.847000000000001","0.848000000000001","0.849000000000001","0.850000000000001","0.851000000000001","0.852000000000001","0.853000000000001","0.854000000000001","0.855000000000001","0.856000000000001","0.857000000000001","0.858000000000001","0.859000000000001","0.860000000000001","0.861000000000001","0.862000000000001","0.863000000000001","0.864000000000001","0.865000000000001","0.866000000000001","0.867000000000001","0.868000000000001","0.869000000000001","0.870000000000001","0.871000000000001","0.872000000000001","0.873000000000001","0.874000000000001","0.875000000000001","0.876000000000001","0.877000000000001","0.878000000000001","0.879000000000001","0.880000000000001","0.881000000000001","0.882000000000001","0.883000000000001","0.884000000000001","0.885000000000001","0.886000000000001","0.887000000000001","0.888000000000001","0.889000000000001","0.890000000000001","0.891000000000001","0.892000000000001","0.893000000000001","0.894000000000001","0.895000000000001","0.896000000000001","0.897000000000001","0.898000000000001","0.899000000000001","0.900000000000001","0.901000000000001","0.902000000000001","0.903000000000001","0.904000000000001","0.905000000000001","0.906000000000001","0.907000000000001","0.908000000000001","0.909000000000001","0.910000000000001","0.911000000000001","0.912000000000001","0.913000000000001","0.914000000000001","0.915000000000001","0.916000000000001","0.917000000000001","0.918000000000001","0.919000000000001","0.920000000000001","0.921000000000001","0.922000000000001","0.923000000000001","0.924000000000001","0.925000000000001","0.926000000000001","0.927000000000001","0.928000000000001","0.929000000000001","0.930000000000001","0.931000000000001","0.932000000000001","0.933000000000001","0.934000000000001","0.935000000000001","0.936000000000001","0.937000000000001","0.938000000000001","0.939000000000001","0.940000000000001","0.941000000000001","0.942000000000001","0.943000000000001","0.944000000000001","0.945000000000001","0.946000000000001","0.947000000000001","0.948000000000001","0.949000000000001","0.950000000000001","0.951000000000001","0.952000000000001","0.953000000000001","0.954000000000001","0.955000000000001","0.956000000000001","0.957000000000001","0.958000000000001","0.959000000000001","0.960000000000001","0.961000000000001","0.962000000000001","0.963000000000001","0.964000000000001","0.965000000000001","0.966000000000001","0.967000000000001","0.968000000000001","0.969000000000001","0.970000000000001","0.971000000000001","0.972000000000001","0.973000000000001","0.974000000000001","0.975000000000001","0.976000000000001","0.977000000000001","0.978000000000001","0.979000000000001","0.980000000000001","0.981000000000001","0.982000000000001","0.983000000000001","0.984000000000001","0.985000000000001","0.986000000000001","0.987000000000001","0.988000000000001","0.989000000000001","0.990000000000001","0.991000000000001","0.992000000000001","0.993000000000001","0.994000000000001","0.995000000000001","0.996000000000001","0.997000000000001","0.998000000000001","0.999000000000001","1.00000000000000"],"var":"lambda_","width":null},{"animate":true,"control_type":"slider","default":99,"display_value":true,"label":"ε: ","vals":["0.0100000000000000","0.0200000000000000","0.0300000000000000","0.0400000000000000","0.0500000000000000","0.0600000000000000","0.0700000000000000","0.0800000000000000","0.0900000000000000","0.100000000000000","0.110000000000000","0.120000000000000","0.130000000000000","0.140000000000000","0.150000000000000","0.160000000000000","0.170000000000000","0.180000000000000","0.190000000000000","0.200000000000000","0.210000000000000","0.220000000000000","0.230000000000000","0.240000000000000","0.250000000000000","0.260000000000000","0.270000000000000","0.280000000000000","0.290000000000000","0.300000000000000","0.310000000000000","0.320000000000000","0.330000000000000","0.340000000000000","0.350000000000000","0.360000000000000","0.370000000000000","0.380000000000000","0.390000000000000","0.400000000000000","0.410000000000000","0.420000000000000","0.430000000000000","0.440000000000000","0.450000000000000","0.460000000000000","0.470000000000000","0.480000000000000","0.490000000000000","0.500000000000000","0.510000000000000","0.520000000000000","0.530000000000000","0.540000000000000","0.550000000000000","0.560000000000000","0.570000000000000","0.580000000000000","0.590000000000000","0.600000000000000","0.610000000000000","0.620000000000000","0.630000000000000","0.640000000000000","0.650000000000000","0.660000000000000","0.670000000000000","0.680000000000000","0.690000000000000","0.700000000000000","0.710000000000000","0.720000000000000","0.730000000000000","0.740000000000000","0.750000000000000","0.760000000000000","0.770000000000000","0.780000000000000","0.790000000000000","0.800000000000000","0.810000000000000","0.820000000000001","0.830000000000001","0.840000000000001","0.850000000000001","0.860000000000001","0.870000000000001","0.880000000000001","0.890000000000001","0.900000000000001","0.910000000000001","0.920000000000001","0.930000000000001","0.940000000000001","0.950000000000001","0.960000000000001","0.970000000000001","0.980000000000001","0.990000000000001","1.00000000000000"],"var":"epsilon","width":null},{"control_type":"input-box","default":"sin(x)","label":"f: ","nrows":1,"readonly":false,"submit_button":null,"type":null,"var":"f","width":null}],"flicker":false,"id":"f89246e5-a570-4439-b58b-24dda1a9dba8","layout":[[["a_b",12,null]],[["lambda_",12,null]],[["epsilon",12,null]],[["f",12,null]],[["",12,null]]],"style":"None"}}︡{"done":true}
︠a8fcf9ec-e5a1-4b79-81c1-910ab6a38d34︠









